# -*- coding=utf-8 -*-
"""
# library: mengzi-zero-shot
# author: huajingyun
# license: Apache License 2.0
# email: huajingyun@chuagnxin.com
# github: https://github.com/Langboat/Mengzi
# description: NLU & NLG (zero-shot) depend on mengzi-t5-base-mt pretrained model
# website: www.langboat.com
"""

from .inference import MengziZeroShot

__all__ = ['MengziZeroShot']
__version__ = '0.1.0'
